    .. _upnp_services_servers_rendering_control_server:

coherence.upnp.services.servers.rendering\_control\_server (module)
-------------------------------------------------------------------

.. automodule:: coherence.upnp.services.servers.rendering_control_server
